@@ -135,20 +135,20 @@ class BitmexOrder:
     def manage_entries(self, symbols):
         for symbol in symbols:
             cp = self.client.get_current_price(symbol)
-            if self.WaitStop:
+            if self.props[symbol].wait_stop:
                 time.sleep(0.5)
                 if self.props[symbol].qty > 0 and cp >= self.props[symbol].entry and self.client.open_contracts(symbol) != 0:
                     self.props[symbol].wait_stop = False
                     self.props[symbol].open = True
                     print("Long Position has been opened, amending Stoploss to",
                           self.props[symbol].SL, flush=True)
-                    self.stoploss_order()
+                    self.stoploss_order(symbol)
                 elif self.props[symbol].qty < 0 and cp <= self.props[symbol].entry and self.client.open_contracts(symbol) != 0:
                     self.props[symbol].wait_stop = False
                     self.props[symbol].open = True
                     print("Short Position has been opened, amending Stoploss to",
                           self.props[symbol].SL, flush=True)
-                    self.stoploss_order()
+                    self.stoploss_order(symbol)
             elif self.props[symbol].open:
                 if self.props[symbol].qty > 0 and cp <= self.props[symbol].SL and self.client.open_contracts(symbol) == 0:
                     self.props[symbol].open = False
